﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2015 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.ComponentModel;
using System.Text.RegularExpressions;
using System.Windows.Forms;

namespace HeuristicLab.BioBoost.Views {
  public partial class FilterDialog : Form {

    public Regex Regex { get; private set; }
    public bool Keep { get; private set; }

    public FilterDialog() {
      InitializeComponent();
      Keep = true;
    }

    protected override bool ProcessCmdKey(ref Message msg, Keys keyData) {
      if (keyData == Keys.Enter) {
        DialogResult = DialogResult.OK;
        Close();
        return true;
      } else if (keyData == Keys.Escape) {
        DialogResult = DialogResult.Cancel;
        Close();
        return true;
      }
      return base.ProcessCmdKey(ref msg, keyData);
    }

    private void textBox1_Validating(object sender, CancelEventArgs e) {
      try {
        Regex = new Regex(textBox1.Text, RegexOptions.IgnoreCase|RegexOptions.IgnorePatternWhitespace);
      } catch (ArgumentException x) {
        textBox1.Select(0, textBox1.Text.Length);
        e.Cancel = true;
        errorProvider1.SetError(textBox1, "not a valid regular expression.");
      }
    }

    private void textBox1_Validated(object sender, EventArgs e) {
      errorProvider1.SetError(textBox1, "");
    }

    private void cancelButton_Click(object sender, EventArgs e) {
      DialogResult = DialogResult.Cancel;
      Close();
    }

    private void okButton_Click(object sender, EventArgs e) {
      DialogResult = DialogResult.OK;
      Close();
    }

    private void keepOption_CheckedChanged(object sender, EventArgs e) {
      Keep = keepOption.Checked;
    }


  }
}
