﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2015 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Parameters;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.BioBoost.Data {

  [StorableClass]
  [Item("CostFactors", "Splits the cost into several differen areas which can are different for different regions.")]
  public class CostFactors : DataItem {

    #region Parameters
    public IValueParameter<ValueParameterCollection> InvestmentParameter { get { return (IValueParameter<ValueParameterCollection>)Parameters["Investment"]; } }
    public IValueParameter<ValueParameterCollection> LaborParameter { get { return (IValueParameter<ValueParameterCollection>)Parameters["Labor"]; } }
    public IValueParameter<ValueParameterCollection> FuelParameter { get { return (IValueParameter<ValueParameterCollection>)Parameters["Fuel"]; } }
    public IValueParameter<ValueParameterCollection> MaintenanceParameter { get { return (IValueParameter<ValueParameterCollection>)Parameters["Maintenance"]; } }
    public IValueParameter<ValueParameterCollection> OtherParameter { get { return (IValueParameter<ValueParameterCollection>)Parameters["Other"]; } }
    #endregion

    #region Parameter Values
    public ValueParameterCollection Investment { get { return InvestmentParameter.Value; } }
    public ValueParameterCollection Labor { get { return LaborParameter.Value; } }
    public ValueParameterCollection Fuel { get { return FuelParameter.Value; } }
    public ValueParameterCollection Maintenance { get { return MaintenanceParameter.Value; } }
    public ValueParameterCollection Other { get { return OtherParameter.Value; } }
    #endregion

    #region Construction & Cloning
    [StorableConstructor]
    protected CostFactors(bool isDeserializing) : base(isDeserializing) { }

    protected CostFactors(CostFactors orig, Cloner cloner) : base(orig, cloner) { }

    public CostFactors() {
      Parameters.Add(new ValueParameter<ValueParameterCollection>("Investment", "The cost factors for investment."));
      Parameters.Add(new ValueParameter<ValueParameterCollection>("Labor", "The cost factors for labor."));
      Parameters.Add(new ValueParameter<ValueParameterCollection>("Fuel", "The cost factors for fuel."));
      Parameters.Add(new ValueParameter<ValueParameterCollection>("Maintenance", "The cost factors for maintenance."));
      Parameters.Add(new ValueParameter<ValueParameterCollection>("Other", "The cost factors for other costs."));
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new CostFactors(this, cloner);
    }
    #endregion


    public override bool IsEquivalentTo(DataItem other) {
      return true;
    }
  }
}
